context("Unit tests")

source("unit/test-ExprBuilder.R", TRUE)

source("unit/test-chain.R", TRUE)
source("unit/test-end_expr.R", TRUE)
source("unit/test-frame_append.R", TRUE)

source("unit/test-select.R", TRUE)
source("unit/test-transmute.R", TRUE)
source("unit/test-filter.R", TRUE)
source("unit/test-arrange.R", TRUE)
source("unit/test-group_by.R", TRUE)
source("unit/test-key_by.R", TRUE)
source("unit/test-mutate.R", TRUE)
source("unit/test-mutate_sd.R", TRUE)
source("unit/test-transmute_sd.R", TRUE)
source("unit/test-filter_sd.R", TRUE)
source("unit/test-filter_on.R", TRUE)
source("unit/test-distinct.R", TRUE)

source("unit/test-left_join.R", TRUE)
source("unit/test-mutate_join.R", TRUE)
source("unit/test-semi_join.R", TRUE)
source("unit/test-inner_join.R", TRUE)
source("unit/test-right_join.R", TRUE)
source("unit/test-anti_join.R", TRUE)
source("unit/test-full_join.R", TRUE)
